/*this program created by zameel shahat 
build WiFi access point using ESP32 Wroom.this will act like electronics business card 
see details at 
https://hackaday.io/project/196781-business-card-size-project-act-as-business-card
*/
#include <WiFi.h>
#include <WebServer.h>
#include <Adafruit_GFX.h>
#include <Adafruit_ST7789.h>
#include <SPI.h>
#include <SD.h>

// Pin definitions for ESP32
#define TFT_MOSI 23
#define TFT_SCLK 18
#define TFT_CS    5
#define TFT_DC    2
#define TFT_RST   4
#define TFT_BL   15  // Optional, depends on your display model
#define SD_CS    13  // Chip Select for SD card

Adafruit_ST7789 tft = Adafruit_ST7789(TFT_CS, TFT_DC, TFT_RST);

// SSID and Password for the ESP32 Access Point
const char* ssid = "zameel business card";
const char* password = "12345678";

// Create a WebServer object on port 80
WebServer server(80);

// HTML code for the webpage
const char index_html[] PROGMEM = R"rawliteral(
<!DOCTYPE html>
<html>
<body>
   <table border="1">
      <tr><td bgcolor="#ADD8E6"; align="center">zameel shahat</td></tr>
      <tr><td bgcolor="#ADD8E6"; align="center">3d.magic.land@gmail.com</td></tr>
      <tr><td bgcolor="#ADD8E6"; align="center">Retired engineer love building </td></tr>
      <tr><td bgcolor="#ADD8E6"; align="center">electronics projects using arduino </td></tr>
      <tr><td align="center">if you want to be in my contact list</td></tr>
      <tr><td align="center">please submit your information</td></tr> 
   <tr>
    <td>
       <form action="/submit" method="POST">
       <label for="input1">Name :</label><br>
       <input type="text" id="input1" name="input1"><br>
       <label for="input2">Email :</label><br>
       <input type="email" id="input2" name="input2"><br>
       <label for="input3">Notes :</label><br>
       <input type="text" id="input3" name="input3"><br><br>
       <input type="submit" value="Submit">
       </form> 
     </td>
     </tr>
   </table> 
</body>
</html>
)rawliteral";

// Initialize display
void initializeDisplay() {
  tft.init(240, 320);
  pinMode(TFT_BL, OUTPUT);
  digitalWrite(TFT_BL, HIGH);
  tft.fillScreen(ST77XX_BLACK);
  tft.setCursor(0, 0);
  tft.setTextColor(ST77XX_WHITE);
}

// Variables to store input values
String input1, input2, input3;

// Process the form data
void handleFormSubmit() {
  if (server.hasArg("input1")) {
    input1 = server.arg("input1");
  }
  if (server.hasArg("input2")) {
    input2 = server.arg("input2");
  }
  if (server.hasArg("input3")) {
    input3 = server.arg("input3");
  }
  String response = "<!DOCTYPE html><html><body><h2>Form Submitted</h2>";
  response += "<p>Name  : " + input1 + "</p>";
  response += "<p>Email : " + input2 + "</p>";
  response += "<p>Notes : " + input3 + "</p>";
  response += "</body></html>";
  server.send(200, "text/html", response);
  
  Serial.println("Name  : " + input1);
  Serial.println("Email : " + input2);
  Serial.println("Notes : " + input3);
  
  initializeDisplay();
  tft.setTextSize(2);
  tft.print("Name : ");
  tft.println(input1);
  tft.print("Email : ");
  tft.println(input2);
  tft.print("Notes : ");
  tft.println(input3);

  // Save data to SD card
  File writeFile = SD.open("/data.txt", FILE_APPEND);
  if (writeFile) {
    writeFile.print("Name: ");
    writeFile.println(input1);
    writeFile.print("Email: ");
    writeFile.println(input2);
    writeFile.print("Notes: ");
    writeFile.println(input3);
    writeFile.println();
    writeFile.close();
    Serial.println("Data written to SD card.");
  } else {
    Serial.println("Error opening file for writing.");
  }
}

void setup() {
  // Start Serial communication for debugging
  Serial.begin(115200);

  // Initialize display
  initializeDisplay();
  tft.setTextSize(2);
  tft.print("Zameel Business card");

  // Initialize SD card
  if (!SD.begin(SD_CS)) {
    Serial.println("SD card initialization failed!");
    tft.println("SD Init Failed!");
    return;
  }
  Serial.println("SD card initialized.");

  // Configure the ESP32 as an Access Point
  WiFi.softAP(ssid, password);

  // Print the IP address
  Serial.println();
  Serial.print("IP Address: ");
  Serial.println(WiFi.softAPIP());

  // Serve the HTML page
  server.on("/", HTTP_GET, []() {
    server.send_P(200, "text/html", index_html);
  });

  // Handle form submission
  server.on("/submit", HTTP_POST, handleFormSubmit);

  // Start the server
  server.begin();
}

void loop() {
  // Handle client requests
  server.handleClient();
}